# yum-plex Cookbook

The yum-plex cookbook takes over management of the default repositoryids that ship with CentOS systems. It allows attribute manipulation of `plex`

## Requirements
### Platforms
- RHEL/CentOS and derivatives
- Fedora

### Chef
- Chef 11+

### Cookbooks
- yum version 3.2.0 or higher
- yum-epel

## Attributes
The following attributes are set by default

```ruby
default['yum']['plex']['repositoryid'] = 'plex'
default['yum']['plex']['enabled'] = true
default['yum']['plex']['managed'] = true
default['yum']['plex']['gpgkey'] = 'https://plex.tv/plex_pub_key.pub'
default['yum']['plex']['gpgcheck'] = true
default['yum']['plex']['description'] = 'Plex Media Server Repository'
default['yum']['plex']['baseurl'] = 'http://plex.r.worldssl.net/PlexMediaServer/fedora-repo/release/$basearch/'
```

## Recipes
- default - Walks through node attributes and feeds a yum_resource
- parameters. The following is an example a resource generated by the
- recipe during compilation.

```ruby
  yum_repository 'plex' do
    baseurl 'http://plex.r.worldssl.net/PlexMediaServer/fedora-repo/release/$basearch/'
    description 'Plex Media Server Repository'
    enabled true
    gpgcheck true
    gpgkey 'https://plex.tv/plex_pub_key.pub'
  end
```

## Usage Example
To disable the `plex` repository through a Role or Environment definition

```
default_attributes(
  'yum' => {
    'plex' => {
      'enabled' => false
    }
  }
)
```

## More Examples
Point the base and debuginfo repositories at an internally hosted server.

```
node.default['yum']['plex']['enabled'] = true
node.default['yum']['plex']['baseurl'] = 'https://internal.example.com/centos/6/os/x86_64'
node.default['yum']['plex']['sslverify'] = false

include_recipe 'yum-plex'
```

## License & Authors
**Author:** Eric Renfro (<psi-jack@linux-help.org>)

**Copyright:** 2016, Linux-Help.org.

```
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
